pub struct Input {
pub source: Option<FHIRUri>,
pub content: Resource,
}Fields
source: Option<FHIRUri>The structure map to apply. This is only needed if the operation is invoked at the resource level. If the $transform operation is invoked on a particular structure map, this will be ignored by the server
content: ResourceThe logical content to transform